cmd

package
v0.0.0-...-7798620 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 20, 2018 License: MIT Imports: 17 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Execute

func Execute()

Execute adds all child commands to the root command and sets flags appropriately. This is called by main.main(). It only needs to happen once to the rootCmd.

Types

type GuttuConfigStruct

type GuttuConfigStruct struct {
	VaultAddress string `mapstructure:"vault_address"`
	Servers      []struct {
		IP            string `mapstructure:"ip"`
		ServerName    string `mapstructure:"server_name"`
		LoginUsername string `mapstructure:"login_username"`
		VaultRole     string `mapstructure:"vault_role"`
	} `mapstructure:"servers"`
}

GuttuConfigStruct struct for holding configuration

type VaultAuthLoginResponse

type VaultAuthLoginResponse struct {
	RequestID     string      `json:"request_id"`
	LeaseID       string      `json:"lease_id"`
	Renewable     bool        `json:"renewable"`
	LeaseDuration int         `json:"lease_duration"`
	Data          interface{} `json:"data"`
	WrapInfo      interface{} `json:"wrap_info"`
	Warnings      interface{} `json:"warnings"`
	Auth          struct {
		ClientToken   string   `json:"client_token"`
		Accessor      string   `json:"accessor"`
		Policies      []string `json:"policies"`
		TokenPolicies []string `json:"token_policies"`
		Metadata      struct {
			Username string `json:"username"`
		} `json:"metadata"`
		LeaseDuration int    `json:"lease_duration"`
		Renewable     bool   `json:"renewable"`
		EntityID      string `json:"entity_id"`
	} `json:"auth"`
}

VaultAuthLoginResponse struct for success response from vault API after logging in

type VaultErrorResponse

type VaultErrorResponse struct {
	Errors []string
}

VaultErrorResponse struct for error response from vault API

type VaultSSHOTPResponse

type VaultSSHOTPResponse struct {
	LeaseID       string `json:"lease_id"`
	Renewable     bool   `json:"renewable"`
	LeaseDuration int    `json:"lease_duration"`
	Data          struct {
		IP       string `json:"ip"`
		Key      string `json:"key"`
		KeyType  string `json:"key_type"`
		Port     int    `json:"port"`
		Username string `json:"username"`
	} `json:"data"`
	Warnings interface{} `json:"warnings"`
	Auth     interface{} `json:"auth"`
}

VaultSSHOTPResponse struct for valid otp response

Jump to